Function amazon_sp_solicitations::apis::solicitations_api::get_solicitation_actions_for_order
source · [−]pub async fn get_solicitation_actions_for_order(
configuration: &Configuration,
amazon_order_id: &str,
marketplace_ids: Vec<String>
) -> Result<GetSolicitationActionsForOrderResponse, Error>Expand description
Returns a list of solicitation types that are available for an order that you specify. A solicitation type is represented by an actions object, which contains a path and query parameter(s). You can use the path and parameter(s) to call an operation that sends a solicitation. Currently only the productReviewAndSellerFeedbackSolicitation solicitation type is available. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.